@@ -9,7 +9,7 @@ use warnings;
 use Template 2.14;
 use Getopt::Long;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use Lemplate::Parser;
 
@@ -495,7 +495,7 @@ local function stash_get(stash, k)
             if type(typ) == "table" then
                 local value = v[key]
                 if type(value) == "function" then
-                    return value()
+                    return value(unpack(typ))
                 end
                 if value then
                     return value
@@ -514,7 +514,7 @@ local function stash_get(stash, k)
                 key = key + 1
             end
             if type(v) ~= "table" then
-                return nil
+                return ''
             end
             v = v[key]
         end
@@ -524,7 +524,7 @@ local function stash_get(stash, k)
     if type(v) == "function" then
         return v()
     end
-    return v
+    return v or ''
 end
 
 local function stash_set(stash, k, v, default)
